==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/GroupSchemaBase.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.GroupSchemaBaseProperties;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GroupSchemaBase
 */
@JsonPropertyOrder({ GroupSchemaBase.JSON_PROPERTY_ID, GroupSchemaBase.JSON_PROPERTY_PROPERTIES,
        GroupSchemaBase.JSON_PROPERTY_REQUIRED, GroupSchemaBase.JSON_PROPERTY_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class GroupSchemaBase implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_PROPERTIES = "properties";
    private GroupSchemaBaseProperties properties;

    public static final String JSON_PROPERTY_REQUIRED = "required";
    private List<String> required = null;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public GroupSchemaBase() {
    }

    /*
     * @JsonCreator public GroupSchemaBase(
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_REQUIRED) List<String> required,
     *
     * @JsonProperty(JSON_PROPERTY_TYPE) String type ) { this(); this.id = id; this.required = required; this.type =
     * type; }
     */

    /**
     * The subschema name
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The subschema name")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    public GroupSchemaBase properties(GroupSchemaBaseProperties properties) {

        this.properties = properties;
        return this;
    }

    /**
     * The &#x60;#base&#x60; object properties
     *
     * @return properties
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The `#base` object properties")
    @JsonProperty(JSON_PROPERTY_PROPERTIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GroupSchemaBaseProperties getProperties() {
        return properties;
    }

    @JsonProperty(JSON_PROPERTY_PROPERTIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProperties(GroupSchemaBaseProperties properties) {
        this.properties = properties;
    }

    /**
     * A collection indicating required property names
     *
     * @return required
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A collection indicating required property names")
    @JsonProperty(JSON_PROPERTY_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getRequired() {
        return required;
    }

    /**
     * The object type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The object type")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GroupSchemaBase groupSchemaBase = (GroupSchemaBase) o;
        return Objects.equals(this.id, groupSchemaBase.id)
                && Objects.equals(this.properties, groupSchemaBase.properties)
                && Objects.equals(this.required, groupSchemaBase.required)
                && Objects.equals(this.type, groupSchemaBase.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, properties, required, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GroupSchemaBase {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    properties: ").append(toIndentedString(properties)).append("\n");
        sb.append("    required: ").append(toIndentedString(required)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/GroupSchemaBase.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.GroupSchemaBaseProperties;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GroupSchemaBase
 */
@JsonPropertyOrder({ GroupSchemaBase.JSON_PROPERTY_ID, GroupSchemaBase.JSON_PROPERTY_PROPERTIES,
        GroupSchemaBase.JSON_PROPERTY_REQUIRED, GroupSchemaBase.JSON_PROPERTY_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class GroupSchemaBase implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_PROPERTIES = "properties";
    private GroupSchemaBaseProperties properties;

    public static final String JSON_PROPERTY_REQUIRED = "required";
    private List<String> required = null;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public GroupSchemaBase() {
    }

    /*
     * @JsonCreator public GroupSchemaBase(
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_REQUIRED) List<String> required,
     *
     * @JsonProperty(JSON_PROPERTY_TYPE) String type ) { this(); this.id = id; this.required = required; this.type =
     * type; }
     */

    /**
     * The subschema name
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The subschema name")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    public GroupSchemaBase properties(GroupSchemaBaseProperties properties) {

        this.properties = properties;
        return this;
    }

    /**
     * The &#x60;#base&#x60; object properties
     *
     * @return properties
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The `#base` object properties")
    @JsonProperty(JSON_PROPERTY_PROPERTIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GroupSchemaBaseProperties getProperties() {
        return properties;
    }

    @JsonProperty(JSON_PROPERTY_PROPERTIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProperties(GroupSchemaBaseProperties properties) {
        this.properties = properties;
    }

    /**
     * A collection indicating required property names
     *
     * @return required
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A collection indicating required property names")
    @JsonProperty(JSON_PROPERTY_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getRequired() {
        return required;
    }

    /**
     * The object type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The object type")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GroupSchemaBase groupSchemaBase = (GroupSchemaBase) o;
        return Objects.equals(this.id, groupSchemaBase.id)
                && Objects.equals(this.properties, groupSchemaBase.properties)
                && Objects.equals(this.required, groupSchemaBase.required)
                && Objects.equals(this.type, groupSchemaBase.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, properties, required, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GroupSchemaBase {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    properties: ").append(toIndentedString(properties)).append("\n");
        sb.append("    required: ").append(toIndentedString(required)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
